# plotCIEChromaticityDiagram()
#
# This function draws the CIE Chromaticity Diagram
#
# Lew Harvey
# Department of Psychology and Neuroscience
# University of Colorado Boulder
#
# 24 February 2018

library("SpecHelpers")

DrawCIEChromaticityDiagram <- function(added_spectral_loci = c(),
                                       added_loci_colors = "black") {
    par(pty = "s") # makes the plot square
    plot(0, 0, type = "n",
         xlim = c(0, 1),
         ylim = c(0, 1),
         xlab = "C.I.E. Chromaticity x",
         ylab = "C.I.E. Chromaticity y",
         main = "C.I.E. Chromaticity Diagram")

    # add color boundary triangle
    # x, y points outside the triangle are not possible,
    # because all x, y, and z coordinates must lie between
    # 0 and 1, inclusively.
    polygon(c(0,0,1), c(0,1,0), border = "gray")


    # add CIE 1931 Spectral Locus
    polygon(CIExyz[,"x"], CIExyz[,"y"], border = "gray")

    # extract x,y of spectral locus for labeling specific points
    w <- CIExyz
    row.names(w) <- w$wavelength

    # label 100s wavelength positions on the spectral locus
    keep1 <- c("400", "500", "600", "700")
    w1 <- w[keep1, ]
    points(y ~ x, data = w1, col = "black", pch = 19, cex = 0.7)
    text(y ~ x, data = w1, labels = keep1, cex = 0.5, pos = 4)

    # add additional loci if present
    if (length(added_spectral_loci) > 0) {
        keep2 <- added_spectral_loci
        w2 <- w[keep2, ]
        points(y ~ x, data = w2, col = added_loci_colors, pch = 19, cex = 0.7)
        text(y ~ x, data = w2, labels = keep2, cex = 0.5, pos = 4)
    }

    # add D65 white point
    D65 <- c(0.31271, 0.32902)
    points(t(D65), cex = 0.6, pch = "+")
    text(t(D65), "D65", pos = 1, cex = 0.5)
}

# DrawCIEChromaticityDiagram()
